@@ -30,7 +30,7 @@ from .. import jsonrpc, diem_types, identifier, utils
 
 
 DEFAULT_CONNECT_TIMEOUT_SECS: float = 2.0
-DEFAULT_TIMEOUT_SECS: float = 5.0
+DEFAULT_TIMEOUT_SECS: float = 30.0
 
 
 class CommandResponseError(Exception):
@@ -47,7 +47,7 @@ class Client:
 
     Initialization:
     ```
-    >>> from diem import offchain, jsonrpc, testnet, LocalAccount
+    >>> from diem import offchain, testnet
     >>>
     >>> jsonrpc_client = testnet.create_client()
     >>> account = testnet.gen_account(client, base_url="http://vasp.com/offchain")
@@ -98,10 +98,10 @@ class Client:
     def __post_init__(self) -> None:
         self.my_compliance_key_account_id = self.account_id(self.my_compliance_key_account_address)
 
-    def send_command(self, command: PaymentCommand, sign: typing.Callable[[bytes], bytes]) -> CommandResponseObject:
+    def send_command(self, command: Command, sign: typing.Callable[[bytes], bytes]) -> CommandResponseObject:
         return self.send_request(
-            request_sender_address=command.my_actor_address,
-            opponent_account_id=command.opponent_actor_obj().address,
+            request_sender_address=command.my_address(),
+            opponent_account_id=command.opponent_address(),
             request_bytes=jws.serialize(command.new_request(), sign),
         )
 
@@ -234,9 +234,9 @@ class Client:
 
     def create_inbound_payment_command(self, cid: str, obj: PaymentObject) -> PaymentCommand:
         if self.is_my_account_id(obj.sender.address):
-            return PaymentCommand(cid=cid, my_actor_address=obj.sender.address, payment=obj, inbound=True)
+            return PaymentCommand(_cid=cid, my_actor_address=obj.sender.address, payment=obj, inbound=True)
         if self.is_my_account_id(obj.receiver.address):
-            return PaymentCommand(cid=cid, my_actor_address=obj.receiver.address, payment=obj, inbound=True)
+            return PaymentCommand(_cid=cid, my_actor_address=obj.receiver.address, payment=obj, inbound=True)
 
         raise command_error(ErrorCode.unknown_address, "unknown actor addresses: {obj}")
 
